# **What is it?**

**proxyauthenticator** is a Python package that support
anyone to add proxy to script easily when working in any local or cloud
environment which uses proxy for in and out connections.


